/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.tree;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Represents an asymmetric host, that is, a host which contains a direction
 * attribute
 * 
 * @author stefan
 * 
 */
public class AsymHost {

	/** member variables */
	public String hostname = "";
	public DistanceLabel<AsymHost> label = new DistanceLabel<AsymHost>();
	public AsymHost parent;
	public List<AsymHost> children = new ArrayList<AsymHost>();

	/** stores the direction of the label */
	public Direction direction;

	/** direction enum */
	public enum Direction {
		UPSTREAM, DOWNSTREAM;
		public Direction reverse() {
			if (this.equals(UPSTREAM))
				return DOWNSTREAM;
			else
				return UPSTREAM;
		}
	};

	/** constructor with direction */
	public AsymHost(String hname, Direction dir) {
		hostname = hname;
		direction = dir;
	}

	/** constructor without direction */
	public AsymHost(String hname) {
		this(hname, null);
	}

	public static AsymHost fromCombinedString(String s) {
		String[] tokens = s.split(":");
		Direction d = tokens[1].equals("U") ? Direction.UPSTREAM : Direction.DOWNSTREAM;
		return new AsymHost(tokens[0], d);
	}

	/** direction sensitive implementation of equals() */
	public boolean equals(Object o) {
		if (o != null && o.getClass().equals(this.getClass())) {
			AsymHost other = (AsymHost) o;
			if ((direction == null || other.direction == null)) {
				if (other.hostname.equals(hostname))
					return true;
			} else {
				if (other.hostname.equals(hostname) && other.direction.equals(this.direction)) {
					return true;
				}
			}
		}
		return false;
	}

	/** string representation */
	public String toString() {
		String h = hostname;
		// if (h.length() > 5)
		// h = h.substring(0, 5);
		if (direction != null) {
			String d = direction.toString().substring(0, 1);
			return h + ":" + d;
		} else {
			return h;
		}
	}

	/** clone() */
	public AsymHost clone() {
		AsymHost nh = new AsymHost(hostname);
		nh.label = label.clone();
		nh.parent = parent;
		nh.children = new ArrayList<AsymHost>(children);
		Collections.copy(nh.children, children);
		nh.direction = direction;
		return nh;
	}
}
