/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.tree;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Represents a Host (without direction attribute for Sequoia and Song's approach)
 * 
 * @author stefan
 *
 */
public class Host {
	/** member variables */
	public String hostname = "";
	public DistanceLabel<Host> label = new DistanceLabel<Host>();
	public Host parent = null;
	public List<Host> children = new ArrayList<Host>();

	/** constructor */
	public Host(String hname) {
		hostname = hname;
	}

	/** toString() */
	public String toString() {
		return hostname;
	}

	/** toString() with label, parent, children */
	public String out() {
		String sChildren = "";
		for (Host h : children) {
			sChildren += h + ", ";
		}
		String ret = String.format("Host: %s\n Label: %s\n Parent: %s\n Children: %s\n", toString(), label, parent, sChildren);
		return ret;
	}

	/** equals() */
	public boolean equals(Object o) {
		if (o.getClass().equals(this.getClass())) {
			Host other = (Host) o;
			if (other.hostname.equals(hostname)) {
				return true;
			}
		}
		return false;
	}

	/** clone() */
	public Host clone() {
		Host nh = new Host(hostname);
		nh.label = label.clone();
		nh.parent = parent;
		nh.children = new ArrayList<Host>(children);
		Collections.copy(nh.children, children);
		return nh;
	}

}
