/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.tree;

import java.util.List;

import sequoia.topology.ITopology;

/**
 * Interface which is implemented by each prediction tree 
 * 
 * @author stefan
 *
 * @param <T>
 */
public interface IPredictionTree<T> {
	
	/** method to embed a host into the tree */
	public void embed(String host);
	
	/** embed a list of hosts */
	public void embedAll(List<String> hosts);

	/** returns all currently embedded hostnames */
	public List<String> getHostnames();
	
	/** returns hosts */
	public List<T> getHosts();

	/** returns the label of a host */
	public DistanceLabel<?> getDLabel(String host);
	
	/** returns a predicted distance using the distance labels */
	public double predictBandwidth(String a, String b);

	/** visualizes a tree */
	public String toString();
	
	/** publish transform function */
	public double transform(double v);
	
	/** get underlying topology */
	public ITopology getTopology();

	/** get measurement ratio */
	public double getMeasurementRatio();
}
