/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.tree;

import java.util.List;

import sequoia.Master;
import sequoia.topology.ITopology;

/**
 * Implements common methods
 */
public abstract class PredictionTree<T> implements IPredictionTree<T> {

	protected ITopology _topology;
	
	/** transforming measurements into distances and vice versa */
	abstract public double transform(double v);

	/** calculating the gromov product */
	protected double gromovProduct(double dxz, double dyz, double dxy) {
		double gromov = 0.5 * (dxz + dyz - dxy);
		if(gromov < 0 && Master.cli_debug)
			System.err.println("Gromov negative (PredictionTree)");
		return gromov;
	}

	/** embed list of hosts */
	public void embedAll(List<String> hosts) {
		for (String host : hosts) {
			try {
				embed(host);
			} catch(Exception e) {
				System.err.println("Node skipped. "+e.toString());
			}
		}
	}

	public ITopology getTopology() {
		return _topology;
	}

}
